@@ -201,8 +201,11 @@ class AptProcess(apb.InstallProgress):
                  "apt_percent":str(200),
                  "action":str(self.action),
                  }
-        self.dbus_service.set_uksc_not_working()
         self.dbus_service.software_apt_signal("apt_finish", kwarg)
+        if self.appname == "ubuntu-kylin-software-center" and self.action == "upgrade":
+            pass
+        else:
+            self.dbus_service.set_uksc_not_working()
 
     def status_change(self, pkg, percent, status):
 #        print "status_change:", self.appname, pkg
@@ -274,7 +277,7 @@ class AptDaemon():
             raise WorkitemError(4, "%s is unreadable file" % path)
         except Exception as e:
             raise WorkitemError(5, e.message)
-
+        self.cache.open()
         pkgName = debfile._sections["Package"]
         debfile.check() #do debfile.check for the next to do debfile.missing_deps
         if 0 == len(debfile.missing_deps):
@@ -289,6 +292,7 @@ class AptDaemon():
     def install_deps(self, path, kwargs=None):
         debfile = DebPackage(path)
         pkgName = debfile._sections["Package"]
+        self.cache.open()
         debfile.check()
         deps = debfile.missing_deps
 
@@ -328,12 +332,6 @@ class AptDaemon():
         if pkg.is_upgradable is False:
             raise WorkitemError(9, "Package %s can't be upgraded" % pkgName)
         pkg.mark_upgrade()
-        if "ubuntu-kylin-software-center" == pkgName:
-            try:
-                os.mknod("/usr/share/ubuntu-kylin-software-center/.uksc_self_upgrade")
-            except:
-                pass
-
         try:
             self.cache.commit(FetchProcess(self.dbus_service,pkgName,AppActions.UPGRADE), AptProcess(self.dbus_service,pkgName,AppActions.UPGRADE))
         except apt.cache.FetchFailedException as error:
